@@ -25,8 +25,9 @@ import utils.dict_utils as obj
 import utils.file_utils as cfu
 import utils.string_utils as csu
 import utils.directory_utils as _dirs
-import config as _config
-_log = _config.log
+import utils.console_utils as _con
+_log = _con.log
+
 
 class TableManager:
     def __init__(self,parent,table_name=None,schema=None,**kwargs):
@@ -458,7 +459,7 @@ class TableManager:
         '''
         drop = csu.sql.drop_table(self.name,self.schema)
         if self.main.connect():
-            _log(f"Dropping Table from database: {self.name}")
+            _log(f"Dropping Table from database: {self.name}","error")
             return self.main.execute_single_statement(drop)
         return True
         # return self.default_data_manager.truncate()
